==> apache-ambari-2.7.9-src.tar.gz: apache-ambari-2.7.9-src/ambari-common/src/main/python/resource_management/libraries/resources/repository.py <==
#!/usr/bin/env python
"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Ambari Agent

"""

_all__ = ["Repository"]

from resource_management.core.base import Resource, ForcedListArgument, ResourceArgument, BooleanArgument

class Repository(Resource):
  action = ForcedListArgument(default="prepare")
  repo_id = ResourceArgument(default=lambda obj: obj.name)
  base_url = ResourceArgument()
  mirror_list = ResourceArgument()
  repo_file_name = ResourceArgument()
  repo_template = ResourceArgument()
  components = ForcedListArgument(default=[]) # ubuntu specific

  """
  'prepare' action only adds repositories information into memory.
  'create' action writes prepared repositories into file (possibly multiple repos into single file)
  """
  actions = Resource.actions + ["prepare", "create","remove"]

==> apache-ambari-3.0.0-src.tar.gz: apache-ambari-3.0.0-src/ambari-common/src/main/python/resource_management/libraries/resources/repository.py <==
#!/usr/bin/env python3
"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Ambari Agent

"""

_all__ = ["Repository"]

from resource_management.core.base import (
  Resource,
  ForcedListArgument,
  ResourceArgument,
  BooleanArgument,
)


class Repository(Resource):
  action = ForcedListArgument(default="prepare")
  repo_id = ResourceArgument(default=lambda obj: obj.name)
  base_url = ResourceArgument()
  mirror_list = ResourceArgument()
  repo_file_name = ResourceArgument()
  repo_template = ResourceArgument()
  components = ForcedListArgument(default=[])  # ubuntu specific

  """
  'prepare' action only adds repositories information into memory.
  'create' action writes prepared repositories into file (possibly multiple repos into single file)
  """
  actions = Resource.actions + ["prepare", "create", "remove"]
